from typing import Any, ClassVar, Dict, List

from typing import overload
import mrpt.pymrpt.mrpt.bayes
import mrpt.pymrpt.mrpt.bayes.CParticleFilter
import mrpt.pymrpt.mrpt.config
import mrpt.pymrpt.mrpt.img
import mrpt.pymrpt.mrpt.maps
import mrpt.pymrpt.mrpt.maps.CMultiMetricMapPDF
import mrpt.pymrpt.mrpt.math
import mrpt.pymrpt.mrpt.obs
import mrpt.pymrpt.mrpt.opengl
import mrpt.pymrpt.mrpt.poses
import mrpt.pymrpt.mrpt.rtti
import mrpt.pymrpt.mrpt.serialization
import mrpt.pymrpt.mrpt.system
import mrpt.pymrpt.mrpt.tfest
import mrpt.pymrpt.mrpt.vision
import mrpt.pymrpt.mrpt.vision.CFeatureExtraction
assocJCBB: TDataAssociationMethod
assocNN: TDataAssociationMethod
icpClassic: TICPAlgorithm
icpCovFiniteDifferences: TICPCovarianceMethod
icpCovLinealMSE: TICPCovarianceMethod
icpLevenbergMarquardt: TICPAlgorithm
metricML: TDataAssociationMetric
metricMaha: TDataAssociationMetric
smCUSTOM_FUNCTION: similarity_method_t
smMETRIC_MAP_MATCHING: similarity_method_t
smOBSERVATION_OVERLAP: similarity_method_t

class CGridMapAligner(CMetricMapsAlignmentAlgorithm):
    class TAlignerMethod:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        amCorrelation: ClassVar[CGridMapAligner.TAlignerMethod] = ...
        amModifiedRANSAC: ClassVar[CGridMapAligner.TAlignerMethod] = ...
        amRobustMatch: ClassVar[CGridMapAligner.TAlignerMethod] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class TConfigParams(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        debug_save_map_pairs: bool
        featsPerSquareMeter: float
        feature_descriptor: mrpt.pymrpt.mrpt.vision.TDescriptorType
        feature_detector_options: mrpt.pymrpt.mrpt.vision.CFeatureExtraction.TOptions
        maxKLd_for_merge: float
        max_ICP_mahadist: float
        methodSelection: CGridMapAligner.TAlignerMethod
        min_ICP_goodness: float
        ransac_SOG_sigma_m: float
        ransac_chi2_quantile: float
        ransac_mahalanobisDistanceThreshold: float
        ransac_minSetSizeRatio: float
        ransac_prob_good_inliers: float
        save_feat_coors: bool
        threshold_delta: float
        threshold_max: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CGridMapAligner.TConfigParams) -> None: ...
        @overload
        def __init__(self, arg0: CGridMapAligner.TConfigParams) -> None: ...
        def assign(self) -> CGridMapAligner.TConfigParams: ...
        @overload
        def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...

    class TReturnInfo(TMetricMapAlignmentResult):
        class TPairPlusDistance:
            dist: float
            idx_other: int
            idx_this: int
            def __init__(self, i1: int, i2: int, d: float) -> None: ...
        correspondences: mrpt.pymrpt.mrpt.tfest.TMatchingPairListTempl_float_t
        correspondences_dists_maha: Any
        goodness: float
        icp_goodness_all_sog_modes: List[float]
        landmarks_map1: mrpt.pymrpt.mrpt.maps.CLandmarksMap
        landmarks_map2: mrpt.pymrpt.mrpt.maps.CLandmarksMap
        noRobustEstimation: mrpt.pymrpt.mrpt.poses.CPose2D
        sog1: Any
        sog2: Any
        sog3: Any
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CGridMapAligner.TReturnInfo) -> None: ...
        def assign(self) -> CGridMapAligner.TReturnInfo: ...
    amCorrelation: ClassVar[CGridMapAligner.TAlignerMethod] = ...
    amModifiedRANSAC: ClassVar[CGridMapAligner.TAlignerMethod] = ...
    amRobustMatch: ClassVar[CGridMapAligner.TAlignerMethod] = ...
    options: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CGridMapAligner) -> None: ...
    @overload
    def __init__(self, arg0: CGridMapAligner) -> None: ...
    def assign(self) -> CGridMapAligner: ...

class CICP(CMetricMapsAlignmentAlgorithm):
    class TConfigParams(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        ALFA: float
        Axy_aprox_derivatives: float
        ICP_algorithm: TICPAlgorithm
        ICP_covariance_method: TICPCovarianceMethod
        LM_initial_lambda: float
        corresponding_points_decimation: int
        covariance_varPoints: float
        doRANSAC: bool
        kernel_rho: float
        maxIterations: int
        minAbsStep_rot: float
        minAbsStep_trans: float
        normalizationStd: float
        onlyUniqueRobust: bool
        ransac_fuseByCorrsMatch: bool
        ransac_fuseMaxDiffPhi: float
        ransac_fuseMaxDiffXY: float
        ransac_mahalanobisDistanceThreshold: float
        ransac_maxSetSize: int
        ransac_minSetSize: int
        ransac_nSimulations: int
        skip_cov_calculation: bool
        skip_quality_calculation: bool
        smallestThresholdDist: float
        thresholdAng: float
        thresholdDist: float
        use_kernel: bool
        @overload
        def __init__(self, arg0: CICP.TConfigParams) -> None: ...
        @overload
        def __init__(self, arg0: CICP.TConfigParams) -> None: ...
        @overload
        def __init__(self) -> None: ...
        def assign(self) -> CICP.TConfigParams: ...
        @overload
        def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
        @overload
        def saveToConfigFile(self, c: mrpt.pymrpt.mrpt.config.CConfigFileBase, s: str) -> None: ...
        @overload
        def saveToConfigFile(classmrpt, conststd) -> void: ...

    class TReturnInfo(TMetricMapAlignmentResult):
        goodness: float
        nIterations: int
        quality: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CICP.TReturnInfo) -> None: ...
        def assign(self) -> CICP.TReturnInfo: ...
    options: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, icpParams) -> None: ...
    @overload
    def __init__(self, arg0: CICP) -> None: ...
    @overload
    def __init__(self, arg0: CICP) -> None: ...
    def assign(self) -> CICP: ...

class CIncrementalMapPartitioner(mrpt.pymrpt.mrpt.serialization.CSerializable):
    class TOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        forceBisectionOnly: bool
        maxKeyFrameDistanceToEval: int
        metricmap: mrpt.pymrpt.mrpt.maps.TSetOfMetricMapInitializers
        minimumNumberElementsEachCluster: int
        mrp: mrpt.pymrpt.mrpt.maps.TMatchingRatioParams
        partitionThreshold: float
        simil_method: similarity_method_t
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CIncrementalMapPartitioner.TOptions) -> None: ...
        @overload
        def __init__(self, arg0: CIncrementalMapPartitioner.TOptions) -> None: ...
        def assign(self) -> CIncrementalMapPartitioner.TOptions: ...
        @overload
        def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
        @overload
        def saveToConfigFile(self, target: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def saveToConfigFile(classmrpt, conststd) -> void: ...
    options: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CIncrementalMapPartitioner) -> None: ...
    @overload
    def __init__(self, arg0: CIncrementalMapPartitioner) -> None: ...
    def CreateObject(self, *args, **kwargs) -> Any: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def addMapFrame(self, frame: mrpt.pymrpt.mrpt.obs.CSensoryFrame, robotPose3D: mrpt.pymrpt.mrpt.poses.CPose3DPDF) -> int: ...
    def assign(self) -> CIncrementalMapPartitioner: ...
    @overload
    def changeCoordinatesOrigin(self, newOrigin: mrpt.pymrpt.mrpt.poses.CPose3D) -> None: ...
    @overload
    def changeCoordinatesOrigin(constclassmrpt) -> void: ...
    @overload
    def changeCoordinatesOriginPoseIndex(self, newOriginPose: int) -> None: ...
    @overload
    def changeCoordinatesOriginPoseIndex(unsignedint) -> void: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def clone(self) -> mrpt.pymrpt.mrpt.rtti.CObject: ...
    def getAdjacencyMatrix(self) -> mrpt.pymrpt.mrpt.math.CMatrixDynamic_double_t: ...
    @overload
    def getNodesCount(self) -> int: ...
    @overload
    def getNodesCount() -> size_t: ...
    def getSequenceOfFrames(self) -> mrpt.pymrpt.mrpt.maps.CSimpleMap: ...
    @overload
    def setSimilarityMethod(self, method: similarity_method_t) -> None: ...
    @overload
    def setSimilarityMethod(enummrpt) -> void: ...
    @overload
    def setSimilarityMethod(self, func) -> None: ...
    @overload
    def setSimilarityMethod(classstd) -> void: ...

class CMetricMapBuilder:
    class TOptions:
        alwaysInsertByClass: mrpt.pymrpt.mrpt.rtti.CListOfClasses
        debugForceInsertion: bool
        enableMapUpdating: bool
        def __init__(self, verb_level_ref: mrpt.pymrpt.mrpt.system.VerbosityLevel) -> None: ...
    def __init__(self) -> None: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def enableMapUpdating(self, enable: bool) -> None: ...
    @overload
    def enableMapUpdating(bool) -> void: ...
    def getCurrentPoseEstimation(self) -> mrpt.pymrpt.mrpt.poses.CPose3DPDF: ...
    @overload
    def getCurrentlyBuiltMap(self, out_map: mrpt.pymrpt.mrpt.maps.CSimpleMap) -> None: ...
    @overload
    def getCurrentlyBuiltMap(classmrpt) -> void: ...
    @overload
    def getCurrentlyBuiltMapSize(self) -> int: ...
    @overload
    def getCurrentlyBuiltMapSize() -> unsignedint: ...
    def getCurrentlyBuiltMetricMap(self) -> mrpt.pymrpt.mrpt.maps.CMultiMetricMap: ...
    @overload
    def initialize(self) -> None: ...
    @overload
    def initialize(self, initialMap: mrpt.pymrpt.mrpt.maps.CSimpleMap) -> None: ...
    @overload
    def initialize(self, initialMap: mrpt.pymrpt.mrpt.maps.CSimpleMap, x0: mrpt.pymrpt.mrpt.poses.CPosePDF) -> None: ...
    @overload
    def loadCurrentMapFromFile(self, fileName: str) -> None: ...
    @overload
    def loadCurrentMapFromFile(conststd) -> void: ...
    def processActionObservation(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observations: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> None: ...
    @overload
    def saveCurrentEstimationToImage(self, file: str) -> None: ...
    @overload
    def saveCurrentEstimationToImage(self, file: str, formatEMF_BMP: bool) -> None: ...
    @overload
    def saveCurrentEstimationToImage(conststd, bool) -> void: ...
    @overload
    def saveCurrentMapToFile(self, fileName: str) -> None: ...
    @overload
    def saveCurrentMapToFile(self, fileName: str, compressGZ: bool) -> None: ...
    @overload
    def saveCurrentMapToFile(conststd, bool) -> void: ...

class CMetricMapBuilderICP(CMetricMapBuilder):
    class TConfigParams(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        insertionAngDistance: float
        insertionLinDistance: float
        localizationAngDistance: float
        localizationLinDistance: float
        mapInitializers: mrpt.pymrpt.mrpt.maps.TSetOfMetricMapInitializers
        matchAgainstTheGrid: bool
        minICPgoodnessToAccept: float
        @overload
        def __init__(self, parent_verbosity_level: mrpt.pymrpt.mrpt.system.VerbosityLevel) -> None: ...
        @overload
        def __init__(self, arg0: CMetricMapBuilderICP.TConfigParams) -> None: ...
        @overload
        def __init__(self, arg0: CMetricMapBuilderICP.TConfigParams) -> None: ...
        def assign(self, other: CMetricMapBuilderICP.TConfigParams) -> CMetricMapBuilderICP.TConfigParams: ...
        @overload
        def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    ICP_options: Any
    ICP_params: CICP.TConfigParams
    def __init__(self) -> None: ...
    def getCurrentPoseEstimation(self) -> mrpt.pymrpt.mrpt.poses.CPose3DPDF: ...
    @overload
    def getCurrentlyBuiltMap(self, out_map: mrpt.pymrpt.mrpt.maps.CSimpleMap) -> None: ...
    @overload
    def getCurrentlyBuiltMap(classmrpt) -> void: ...
    @overload
    def getCurrentlyBuiltMapSize(self) -> int: ...
    @overload
    def getCurrentlyBuiltMapSize() -> unsignedint: ...
    def getCurrentlyBuiltMetricMap(self) -> mrpt.pymrpt.mrpt.maps.CMultiMetricMap: ...
    def initialize(self, *args, **kwargs) -> Any: ...
    def processActionObservation(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, in_SF: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> None: ...
    def processObservation(self, *args, **kwargs) -> Any: ...
    @overload
    def saveCurrentEstimationToImage(self, file: str) -> None: ...
    @overload
    def saveCurrentEstimationToImage(self, file: str, formatEMF_BMP: bool) -> None: ...
    @overload
    def saveCurrentEstimationToImage(conststd, bool) -> void: ...
    def setCurrentMapFile(self, mapFile: str) -> None: ...

class CMetricMapBuilderRBPF(CMetricMapBuilder):
    class TConstructionOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions
        insertionAngDistance: float
        insertionLinDistance: float
        localizeAngDistance: float
        localizeLinDistance: float
        mapsInitializers: mrpt.pymrpt.mrpt.maps.TSetOfMetricMapInitializers
        predictionOptions: mrpt.pymrpt.mrpt.maps.CMultiMetricMapPDF.TPredictionParams
        verbosity_level: mrpt.pymrpt.mrpt.system.VerbosityLevel
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CMetricMapBuilderRBPF.TConstructionOptions) -> None: ...
        @overload
        def __init__(self, arg0: CMetricMapBuilderRBPF.TConstructionOptions) -> None: ...
        def assign(self) -> CMetricMapBuilderRBPF.TConstructionOptions: ...
        @overload
        def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...

    class TStats:
        observationsInserted: bool
        def __init__(self) -> None: ...
    m_statsLastIteration: Any
    mapPDF: mrpt.pymrpt.mrpt.maps.CMultiMetricMapPDF
    @overload
    def __init__(self, initializationOptions) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self, src: CMetricMapBuilderRBPF) -> CMetricMapBuilderRBPF: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def drawCurrentEstimationToImage(self, img: mrpt.pymrpt.mrpt.img.CCanvas) -> None: ...
    @overload
    def drawCurrentEstimationToImage(classmrpt) -> void: ...
    @overload
    def getCurrentJointEntropy(self) -> float: ...
    @overload
    def getCurrentJointEntropy() -> double: ...
    @overload
    def getCurrentMostLikelyPath(self, outPath: List[mrpt.pymrpt.mrpt.math.TPose3D]) -> None: ...
    @overload
    def getCurrentMostLikelyPath(classstd) -> void: ...
    def getCurrentPoseEstimation(self) -> mrpt.pymrpt.mrpt.poses.CPose3DPDF: ...
    @overload
    def getCurrentlyBuiltMap(self, out_map: mrpt.pymrpt.mrpt.maps.CSimpleMap) -> None: ...
    @overload
    def getCurrentlyBuiltMap(classmrpt) -> void: ...
    @overload
    def getCurrentlyBuiltMapSize(self) -> int: ...
    @overload
    def getCurrentlyBuiltMapSize() -> unsignedint: ...
    def getCurrentlyBuiltMetricMap(self) -> mrpt.pymrpt.mrpt.maps.CMultiMetricMap: ...
    @overload
    def initialize(self) -> None: ...
    @overload
    def initialize(self, initialMap: mrpt.pymrpt.mrpt.maps.CSimpleMap) -> None: ...
    @overload
    def initialize(self, initialMap: mrpt.pymrpt.mrpt.maps.CSimpleMap, x0: mrpt.pymrpt.mrpt.poses.CPosePDF) -> None: ...
    def processActionObservation(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observations: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> None: ...
    @overload
    def saveCurrentEstimationToImage(self, file: str) -> None: ...
    @overload
    def saveCurrentEstimationToImage(self, file: str, formatEMF_BMP: bool) -> None: ...
    @overload
    def saveCurrentEstimationToImage(conststd, bool) -> void: ...
    @overload
    def saveCurrentPathEstimationToTextFile(self, fil: str) -> None: ...
    @overload
    def saveCurrentPathEstimationToTextFile(conststd) -> void: ...

class CMetricMapsAlignmentAlgorithm:
    def __init__(self, *args, **kwargs) -> None: ...
    def assign(self) -> CMetricMapsAlignmentAlgorithm: ...

class CMonteCarloLocalization2D(mrpt.pymrpt.mrpt.poses.CPosePDFParticles, PF_implementation_mrpt_math_TPose2D_mrpt_slam_CMonteCarloLocalization2D_mrpt_bayes_particle_storage_mode_VALUE_t):
    options: TMonteCarloLocalizationParams
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, M: int) -> None: ...
    def PF_SLAM_computeObservationLikelihoodForParticle(self, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions, particleIndexForMap: int, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, x: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(self, particleData: mrpt.pymrpt.mrpt.math.TPose2D, newPose: mrpt.pymrpt.mrpt.math.TPose3D) -> None: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(structmrpt, conststructmrpt) -> void: ...
    def assign(self) -> CMonteCarloLocalization2D: ...
    def getLastPose(self, i: int, is_valid_pose: bool) -> mrpt.pymrpt.mrpt.math.TPose3D: ...
    def getVisualization(self) -> mrpt.pymrpt.mrpt.opengl.CSetOfObjects: ...
    def prediction_and_update_pfAuxiliaryPFOptimal(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions) -> None: ...
    def prediction_and_update_pfAuxiliaryPFStandard(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions) -> None: ...
    def prediction_and_update_pfStandardProposal(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float, particlesCount: int) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float, particlesCount: int, x_min: float) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float, particlesCount: int, x_min: float, x_max: float) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float, particlesCount: int, x_min: float, x_max: float, y_min: float) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float, particlesCount: int, x_min: float, x_max: float, y_min: float, y_max: float) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float, particlesCount: int, x_min: float, x_max: float, y_min: float, y_max: float, phi_min: float) -> None: ...
    @overload
    def resetUniformFreeSpace(self, theMap: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, freeCellsThreshold: float, particlesCount: int, x_min: float, x_max: float, y_min: float, y_max: float, phi_min: float, phi_max: float) -> None: ...

class CMonteCarloLocalization3D(mrpt.pymrpt.mrpt.poses.CPose3DPDFParticles, PF_implementation_mrpt_math_TPose3D_mrpt_slam_CMonteCarloLocalization3D_mrpt_bayes_particle_storage_mode_VALUE_t):
    options: TMonteCarloLocalizationParams
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, M: int) -> None: ...
    def PF_SLAM_computeObservationLikelihoodForParticle(self, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions, particleIndexForMap: int, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, x: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(self, particleData: mrpt.pymrpt.mrpt.math.TPose3D, newPose: mrpt.pymrpt.mrpt.math.TPose3D) -> None: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(structmrpt, conststructmrpt) -> void: ...
    def assign(self) -> CMonteCarloLocalization3D: ...
    def getLastPose(self, i: int, is_valid_pose: bool) -> mrpt.pymrpt.mrpt.math.TPose3D: ...
    def getVisualization(self) -> mrpt.pymrpt.mrpt.opengl.CSetOfObjects: ...
    def prediction_and_update_pfAuxiliaryPFOptimal(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions) -> None: ...
    def prediction_and_update_pfAuxiliaryPFStandard(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions) -> None: ...
    def prediction_and_update_pfStandardProposal(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions) -> None: ...

class COccupancyGridMapFeatureExtractor(mrpt.pymrpt.mrpt.system.CObserver):
    @overload
    def __init__(self, arg0: COccupancyGridMapFeatureExtractor) -> None: ...
    @overload
    def __init__(self, arg0: COccupancyGridMapFeatureExtractor) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> COccupancyGridMapFeatureExtractor: ...
    @overload
    def extractFeatures(self, grid: mrpt.pymrpt.mrpt.maps.COccupancyGridMap2D, outMap: mrpt.pymrpt.mrpt.maps.CLandmarksMap, number_of_features: int, descriptors: mrpt.pymrpt.mrpt.vision.TDescriptorType, feat_options: mrpt.pymrpt.mrpt.vision.CFeatureExtraction.TOptions) -> None: ...
    @overload
    def extractFeatures(constclassmrpt, classmrpt, size_t, constenummrpt, conststructmrpt) -> void: ...
    def uncached_extractFeatures(self, *args, **kwargs) -> Any: ...

class CRangeBearingKFSLAM(mrpt.pymrpt.mrpt.bayes.CKalmanFilterCapable_7UL_3UL_3UL_7UL_double_t):
    class TDataAssocInfo:
        Y_pred_covs: mrpt.pymrpt.mrpt.math.CMatrixDynamic_double_t
        Y_pred_means: mrpt.pymrpt.mrpt.math.CMatrixDynamic_double_t
        newly_inserted_landmarks: Dict[int,int]
        predictions_IDs: List[int]
        results: TDataAssociationResults
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CRangeBearingKFSLAM.TDataAssocInfo) -> None: ...
        def assign(self) -> CRangeBearingKFSLAM.TDataAssocInfo: ...
        @overload
        def clear(self) -> None: ...
        @overload
        def clear() -> void: ...

    class TOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        create_simplemap: bool
        data_assoc_IC_chi2_thres: float
        data_assoc_IC_metric: TDataAssociationMetric
        data_assoc_IC_ml_threshold: float
        data_assoc_method: TDataAssociationMethod
        data_assoc_metric: TDataAssociationMetric
        doPartitioningExperiment: bool
        force_ignore_odometry: bool
        partitioningMethod: int
        quantiles_3D_representation: float
        std_odo_z_additional: float
        std_sensor_pitch: float
        std_sensor_range: float
        std_sensor_yaw: float
        stds_Q_no_odo: Any
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CRangeBearingKFSLAM.TOptions) -> None: ...
        @overload
        def __init__(self, arg0: CRangeBearingKFSLAM.TOptions) -> None: ...
        def assign(self) -> CRangeBearingKFSLAM.TOptions: ...
        @overload
        def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    options: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CRangeBearingKFSLAM) -> None: ...
    @overload
    def __init__(self, arg0: CRangeBearingKFSLAM) -> None: ...
    @overload
    def getAs3DObject(self, outObj: mrpt.pymrpt.mrpt.opengl.CSetOfObjects) -> None: ...
    @overload
    def getAs3DObject(classstd) -> void: ...
    @overload
    def getCurrentRobotPose(self, out_robotPose: mrpt.pymrpt.mrpt.poses.CPose3DQuatPDFGaussian) -> None: ...
    @overload
    def getCurrentRobotPose(classmrpt) -> void: ...
    @overload
    def getCurrentRobotPose(self, out_robotPose: mrpt.pymrpt.mrpt.poses.CPose3DPDFGaussian) -> None: ...
    @overload
    def getCurrentRobotPose(classmrpt) -> void: ...
    def getCurrentRobotPoseMean(self) -> mrpt.pymrpt.mrpt.poses.CPose3DQuat: ...
    def getLastDataAssociation(self, *args, **kwargs) -> Any: ...
    @overload
    def loadOptions(self, ini: mrpt.pymrpt.mrpt.config.CConfigFileBase) -> None: ...
    @overload
    def loadOptions(constclassmrpt) -> void: ...
    def mapPartitionOptions(self) -> CIncrementalMapPartitioner.TOptions: ...
    def processActionObservation(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, SF: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> None: ...
    def reconsiderPartitionsNow(self, *args, **kwargs) -> Any: ...
    @overload
    def reset(self) -> None: ...
    @overload
    def reset() -> void: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float, styleLandmarks: str) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float, styleLandmarks: str, stylePath: str) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float, styleLandmarks: str, stylePath: str, styleRobot: str) -> None: ...

class CRangeBearingKFSLAM2D(mrpt.pymrpt.mrpt.bayes.CKalmanFilterCapable_3UL_2UL_2UL_3UL_double_t):
    class TDataAssocInfo:
        Y_pred_covs: mrpt.pymrpt.mrpt.math.CMatrixDynamic_double_t
        Y_pred_means: mrpt.pymrpt.mrpt.math.CMatrixDynamic_double_t
        newly_inserted_landmarks: Dict[int,int]
        predictions_IDs: List[int]
        results: TDataAssociationResults
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CRangeBearingKFSLAM2D.TDataAssocInfo) -> None: ...
        def assign(self) -> CRangeBearingKFSLAM2D.TDataAssocInfo: ...
        @overload
        def clear(self) -> None: ...
        @overload
        def clear() -> void: ...

    class TOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        create_simplemap: bool
        data_assoc_IC_chi2_thres: float
        data_assoc_IC_metric: TDataAssociationMetric
        data_assoc_IC_ml_threshold: float
        data_assoc_method: TDataAssociationMethod
        data_assoc_metric: TDataAssociationMetric
        quantiles_3D_representation: float
        std_sensor_range: float
        std_sensor_yaw: float
        stds_Q_no_odo: Any
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CRangeBearingKFSLAM2D.TOptions) -> None: ...
        @overload
        def __init__(self, arg0: CRangeBearingKFSLAM2D.TOptions) -> None: ...
        def assign(self) -> CRangeBearingKFSLAM2D.TOptions: ...
        @overload
        def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    options: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CRangeBearingKFSLAM2D) -> None: ...
    @overload
    def __init__(self, arg0: CRangeBearingKFSLAM2D) -> None: ...
    @overload
    def getAs3DObject(self, outObj: mrpt.pymrpt.mrpt.opengl.CSetOfObjects) -> None: ...
    @overload
    def getAs3DObject(classstd) -> void: ...
    @overload
    def getCurrentRobotPose(self, out_robotPose: mrpt.pymrpt.mrpt.poses.CPosePDFGaussian) -> None: ...
    @overload
    def getCurrentRobotPose(classmrpt) -> void: ...
    def getLastDataAssociation(self, *args, **kwargs) -> Any: ...
    @overload
    def loadOptions(self, ini: mrpt.pymrpt.mrpt.config.CConfigFileBase) -> None: ...
    @overload
    def loadOptions(constclassmrpt) -> void: ...
    def processActionObservation(self, action: mrpt.pymrpt.mrpt.obs.CActionCollection, SF: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> None: ...
    @overload
    def reset(self) -> None: ...
    @overload
    def reset() -> void: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float, styleLandmarks: str) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float, styleLandmarks: str, stylePath: str) -> None: ...
    @overload
    def saveMapAndPath2DRepresentationAsMATLABFile(self, fil: str, stdCount: float, styleLandmarks: str, stylePath: str, styleRobot: str) -> None: ...

class CRejectionSamplingRangeOnlyLocalization(mrpt.pymrpt.mrpt.bayes.CRejectionSamplingCapable_mrpt_poses_CPose2D_mrpt_bayes_particle_storage_mode_POINTER_t):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CRejectionSamplingRangeOnlyLocalization) -> None: ...
    @overload
    def __init__(self, arg0: CRejectionSamplingRangeOnlyLocalization) -> None: ...
    def assign(self) -> CRejectionSamplingRangeOnlyLocalization: ...
    @overload
    def setParams(self, beaconsMap: mrpt.pymrpt.mrpt.maps.CLandmarksMap, observation: mrpt.pymrpt.mrpt.obs.CObservationBeaconRanges, sigmaRanges: float, oldPose: mrpt.pymrpt.mrpt.poses.CPose2D) -> bool: ...
    @overload
    def setParams(self, beaconsMap: mrpt.pymrpt.mrpt.maps.CLandmarksMap, observation: mrpt.pymrpt.mrpt.obs.CObservationBeaconRanges, sigmaRanges: float, oldPose: mrpt.pymrpt.mrpt.poses.CPose2D, robot_z: float) -> bool: ...
    @overload
    def setParams(self, beaconsMap: mrpt.pymrpt.mrpt.maps.CLandmarksMap, observation: mrpt.pymrpt.mrpt.obs.CObservationBeaconRanges, sigmaRanges: float, oldPose: mrpt.pymrpt.mrpt.poses.CPose2D, robot_z: float, autoCheckAngleRanges: bool) -> bool: ...

class PF_implementation_mrpt_maps_CRBPFParticleData_mrpt_maps_CMultiMetricMapPDF_mrpt_bayes_particle_storage_mode_POINTER_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: PF_implementation_mrpt_maps_CRBPFParticleData_mrpt_maps_CMultiMetricMapPDF_mrpt_bayes_particle_storage_mode_POINTER_t) -> None: ...
    def PF_SLAM_computeObservationLikelihoodForParticle(self, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions, particleIndexForMap: int, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, x: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(self, particleData, newPose: mrpt.pymrpt.mrpt.math.TPose3D) -> None: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(classmrpt, conststructmrpt) -> void: ...
    @overload
    def PF_SLAM_implementation_doWeHaveValidObservations(self, particles, sf: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> bool: ...
    @overload
    def PF_SLAM_implementation_doWeHaveValidObservations(constclassstd, mrpt, constclassmrpt) -> bool: ...
    @overload
    def PF_SLAM_implementation_skipRobotMovement(self) -> bool: ...
    @overload
    def PF_SLAM_implementation_skipRobotMovement() -> bool: ...
    def assign(self) -> PF_implementation_mrpt_maps_CRBPFParticleData_mrpt_maps_CMultiMetricMapPDF_mrpt_bayes_particle_storage_mode_POINTER_t: ...
    def getLastPose(self, i: int, is_valid_pose: bool) -> mrpt.pymrpt.mrpt.math.TPose3D: ...

class PF_implementation_mrpt_math_TPose2D_mrpt_slam_CMonteCarloLocalization2D_mrpt_bayes_particle_storage_mode_VALUE_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: PF_implementation_mrpt_math_TPose2D_mrpt_slam_CMonteCarloLocalization2D_mrpt_bayes_particle_storage_mode_VALUE_t) -> None: ...
    def PF_SLAM_computeObservationLikelihoodForParticle(self, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions, particleIndexForMap: int, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, x: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(self, particleData: mrpt.pymrpt.mrpt.math.TPose2D, newPose: mrpt.pymrpt.mrpt.math.TPose3D) -> None: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(structmrpt, conststructmrpt) -> void: ...
    @overload
    def PF_SLAM_implementation_doWeHaveValidObservations(self, particles, sf: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> bool: ...
    @overload
    def PF_SLAM_implementation_doWeHaveValidObservations(constclassstd, mrpt, constclassmrpt) -> bool: ...
    @overload
    def PF_SLAM_implementation_skipRobotMovement(self) -> bool: ...
    @overload
    def PF_SLAM_implementation_skipRobotMovement() -> bool: ...
    def assign(self) -> PF_implementation_mrpt_math_TPose2D_mrpt_slam_CMonteCarloLocalization2D_mrpt_bayes_particle_storage_mode_VALUE_t: ...
    def getLastPose(self, i: int, is_valid_pose: bool) -> mrpt.pymrpt.mrpt.math.TPose3D: ...

class PF_implementation_mrpt_math_TPose3D_mrpt_slam_CMonteCarloLocalization3D_mrpt_bayes_particle_storage_mode_VALUE_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: PF_implementation_mrpt_math_TPose3D_mrpt_slam_CMonteCarloLocalization3D_mrpt_bayes_particle_storage_mode_VALUE_t) -> None: ...
    def PF_SLAM_computeObservationLikelihoodForParticle(self, PF_options: mrpt.pymrpt.mrpt.bayes.CParticleFilter.TParticleFilterOptions, particleIndexForMap: int, observation: mrpt.pymrpt.mrpt.obs.CSensoryFrame, x: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(self, particleData: mrpt.pymrpt.mrpt.math.TPose3D, newPose: mrpt.pymrpt.mrpt.math.TPose3D) -> None: ...
    @overload
    def PF_SLAM_implementation_custom_update_particle_with_new_pose(structmrpt, conststructmrpt) -> void: ...
    @overload
    def PF_SLAM_implementation_doWeHaveValidObservations(self, particles, sf: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> bool: ...
    @overload
    def PF_SLAM_implementation_doWeHaveValidObservations(constclassstd, mrpt, constclassmrpt) -> bool: ...
    @overload
    def PF_SLAM_implementation_skipRobotMovement(self) -> bool: ...
    @overload
    def PF_SLAM_implementation_skipRobotMovement() -> bool: ...
    def assign(self) -> PF_implementation_mrpt_math_TPose3D_mrpt_slam_CMonteCarloLocalization3D_mrpt_bayes_particle_storage_mode_VALUE_t: ...
    def getLastPose(self, i: int, is_valid_pose: bool) -> mrpt.pymrpt.mrpt.math.TPose3D: ...

class TDataAssociationMethod:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    assocJCBB: ClassVar[TDataAssociationMethod] = ...
    assocNN: ClassVar[TDataAssociationMethod] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TDataAssociationMetric:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    metricML: ClassVar[TDataAssociationMetric] = ...
    metricMaha: ClassVar[TDataAssociationMetric] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TDataAssociationResults:
    associations: Dict[int,int]
    distance: float
    indiv_compatibility: Any
    indiv_compatibility_counts: List[int]
    indiv_distances: mrpt.pymrpt.mrpt.math.CMatrixDynamic_double_t
    nNodesExploredInJCBB: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TDataAssociationResults) -> None: ...
    def assign(self) -> TDataAssociationResults: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...

class TICPAlgorithm:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    icpClassic: ClassVar[TICPAlgorithm] = ...
    icpLevenbergMarquardt: ClassVar[TICPAlgorithm] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TICPCovarianceMethod:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    icpCovFiniteDifferences: ClassVar[TICPCovarianceMethod] = ...
    icpCovLinealMSE: ClassVar[TICPCovarianceMethod] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TKLDParams(mrpt.pymrpt.mrpt.config.CLoadableOptions):
    KLD_binSize_PHI: float
    KLD_binSize_XY: float
    KLD_delta: float
    KLD_epsilon: float
    KLD_maxSampleSize: int
    KLD_minSampleSize: int
    KLD_minSamplesPerBin: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TKLDParams) -> None: ...
    @overload
    def __init__(self, arg0: TKLDParams) -> None: ...
    def assign(self) -> TKLDParams: ...
    @overload
    def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...

class TMetricMapAlignmentResult:
    executionTime: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TMetricMapAlignmentResult) -> None: ...
    def assign(self) -> TMetricMapAlignmentResult: ...

class TMonteCarloLocalizationParams:
    KLD_params: TKLDParams
    metricMap: mrpt.pymrpt.mrpt.maps.CMetricMap
    metricMaps: List[mrpt.pymrpt.mrpt.maps.CMetricMap]
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TMonteCarloLocalizationParams) -> None: ...
    def assign(self) -> TMonteCarloLocalizationParams: ...

class map_keyframe_t:
    kf_id: int
    metric_map: mrpt.pymrpt.mrpt.maps.CMultiMetricMap
    raw_observations: mrpt.pymrpt.mrpt.obs.CSensoryFrame
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: map_keyframe_t) -> None: ...
    def assign(self) -> map_keyframe_t: ...

class similarity_method_t:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    smCUSTOM_FUNCTION: ClassVar[similarity_method_t] = ...
    smMETRIC_MAP_MATCHING: ClassVar[similarity_method_t] = ...
    smOBSERVATION_OVERLAP: ClassVar[similarity_method_t] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

@overload
def observationsOverlap(o1: mrpt.pymrpt.mrpt.obs.CObservation, o2: mrpt.pymrpt.mrpt.obs.CObservation) -> float: ...
@overload
def observationsOverlap(o1: mrpt.pymrpt.mrpt.obs.CObservation, o2: mrpt.pymrpt.mrpt.obs.CObservation, pose_o2_wrt_o1: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
@overload
def observationsOverlap(o1: mrpt.pymrpt.mrpt.obs.CObservation, o2: mrpt.pymrpt.mrpt.obs.CObservation) -> float: ...
@overload
def observationsOverlap(o1: mrpt.pymrpt.mrpt.obs.CObservation, o2: mrpt.pymrpt.mrpt.obs.CObservation, pose_o2_wrt_o1: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
@overload
def observationsOverlap(sf1: mrpt.pymrpt.mrpt.obs.CSensoryFrame, sf2: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> float: ...
@overload
def observationsOverlap(sf1: mrpt.pymrpt.mrpt.obs.CSensoryFrame, sf2: mrpt.pymrpt.mrpt.obs.CSensoryFrame, pose_sf2_wrt_sf1: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
@overload
def observationsOverlap(sf1: mrpt.pymrpt.mrpt.obs.CSensoryFrame, sf2: mrpt.pymrpt.mrpt.obs.CSensoryFrame) -> float: ...
@overload
def observationsOverlap(sf1: mrpt.pymrpt.mrpt.obs.CSensoryFrame, sf2: mrpt.pymrpt.mrpt.obs.CSensoryFrame, pose_sf2_wrt_sf1: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...



from typing import Any, ClassVar, List

from typing import overload
import mrpt.pymrpt.mrpt.math
import mrpt.pymrpt.mrpt.serialization
import mrpt.pymrpt.std.chrono
NMEA_GGA: gnss_message_type_t
NMEA_GLL: gnss_message_type_t
NMEA_GSA: gnss_message_type_t
NMEA_GSV: gnss_message_type_t
NMEA_MSS: gnss_message_type_t
NMEA_RMC: gnss_message_type_t
NMEA_VTG: gnss_message_type_t
NMEA_ZDA: gnss_message_type_t
NV_OEM6_ALIGNBSLNENU: gnss_message_type_t
NV_OEM6_ALIGNBSLNXYZ: gnss_message_type_t
NV_OEM6_ALIGNDOP: gnss_message_type_t
NV_OEM6_BESTPOS: gnss_message_type_t
NV_OEM6_BESTSATS: gnss_message_type_t
NV_OEM6_BESTUTM: gnss_message_type_t
NV_OEM6_BESTVEL: gnss_message_type_t
NV_OEM6_BESTXYZ: gnss_message_type_t
NV_OEM6_CLOCKSTEERING: gnss_message_type_t
NV_OEM6_GENERIC_FRAME: gnss_message_type_t
NV_OEM6_GENERIC_SHORT_FRAME: gnss_message_type_t
NV_OEM6_GPGGA: gnss_message_type_t
NV_OEM6_GPGGARTK: gnss_message_type_t
NV_OEM6_GPGLL: gnss_message_type_t
NV_OEM6_GPGSA: gnss_message_type_t
NV_OEM6_GPGSV: gnss_message_type_t
NV_OEM6_GPHDT: gnss_message_type_t
NV_OEM6_GPRMC: gnss_message_type_t
NV_OEM6_GPVTG: gnss_message_type_t
NV_OEM6_GPZDA: gnss_message_type_t
NV_OEM6_INSATTS: gnss_message_type_t
NV_OEM6_INSCOVS: gnss_message_type_t
NV_OEM6_INSPVAS: gnss_message_type_t
NV_OEM6_INSVELS: gnss_message_type_t
NV_OEM6_IONUTC: gnss_message_type_t
NV_OEM6_MARK2POS: gnss_message_type_t
NV_OEM6_MARK2TIME: gnss_message_type_t
NV_OEM6_MARKPOS: gnss_message_type_t
NV_OEM6_MARKTIME: gnss_message_type_t
NV_OEM6_MSG2ENUM: gnss_message_type_t
NV_OEM6_PPPPOS: gnss_message_type_t
NV_OEM6_RANGECMP: gnss_message_type_t
NV_OEM6_RAWEPHEM: gnss_message_type_t
NV_OEM6_RAWIMUS: gnss_message_type_t
NV_OEM6_RXSTATUS: gnss_message_type_t
NV_OEM6_VERSION: gnss_message_type_t
TOPCON_PZS: gnss_message_type_t
TOPCON_SATS: gnss_message_type_t

class Message_NMEA_GGA(gnss_message):
    class content_t:
        HDOP: float
        UTCTime: UTC_time
        altitude_meters: float
        corrected_orthometric_altitude: float
        fix_quality: int
        geoidal_distance: float
        latitude_degrees: float
        longitude_degrees: float
        orthometric_altitude: float
        satellitesUsed: int
        thereis_HDOP: bool
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NMEA_GGA.content_t) -> None: ...
        def assign(self) -> Message_NMEA_GGA.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_GGA) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_GGA) -> None: ...
    def assign(self) -> Message_NMEA_GGA: ...

class Message_NMEA_GLL(gnss_message):
    class content_t:
        UTCTime: UTC_time
        latitude_degrees: float
        longitude_degrees: float
        validity_char: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NMEA_GLL.content_t) -> None: ...
        def assign(self) -> Message_NMEA_GLL.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_GLL) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_GLL) -> None: ...
    def assign(self) -> Message_NMEA_GLL: ...

class Message_NMEA_GSA(gnss_message):
    class content_t:
        HDOP: float
        PDOP: float
        VDOP: float
        auto_selection_fix: str
        fix_2D_3D: str
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NMEA_GSA.content_t) -> None: ...
        def assign(self) -> Message_NMEA_GSA.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_GSA) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_GSA) -> None: ...
    def assign(self) -> Message_NMEA_GSA: ...

class Message_NMEA_RMC(gnss_message):
    class content_t:
        UTCTime: UTC_time
        date_day: int
        date_month: int
        date_year: int
        direction_degrees: float
        latitude_degrees: float
        longitude_degrees: float
        magnetic_dir: float
        positioning_mode: str
        speed_knots: float
        validity_char: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NMEA_RMC.content_t) -> None: ...
        def assign(self) -> Message_NMEA_RMC.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_RMC) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_RMC) -> None: ...
    def assign(self) -> Message_NMEA_RMC: ...
    def getDateAsTimestamp(self) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...

class Message_NMEA_VTG(gnss_message):
    class content_t:
        ground_speed_kmh: float
        ground_speed_knots: float
        magnetic_track: float
        true_track: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NMEA_VTG.content_t) -> None: ...
        def assign(self) -> Message_NMEA_VTG.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_VTG) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_VTG) -> None: ...
    def assign(self) -> Message_NMEA_VTG: ...

class Message_NMEA_ZDA(gnss_message):
    class content_t:
        UTCTime: UTC_time
        date_day: int
        date_month: int
        date_year: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NMEA_ZDA.content_t) -> None: ...
        def assign(self) -> Message_NMEA_ZDA.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_ZDA) -> None: ...
    @overload
    def __init__(self, arg0: Message_NMEA_ZDA) -> None: ...
    def assign(self) -> Message_NMEA_ZDA: ...
    def getDateAsTimestamp(self) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
    def getDateTimeAsTimestamp(self) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...

class Message_NV_OEM6_BESTPOS(gnss_message):
    class content_t:
        crc: int
        datum_id: int
        diff_age: float
        ext_sol_stat: int
        galileo_beidou_mask: int
        gps_glonass_mask: int
        header: nv_oem6_header_t
        hgt: float
        hgt_sigma: float
        lat: float
        lat_sigma: float
        lon: float
        lon_sigma: float
        num_sats_sol: int
        num_sats_sol_L1: int
        num_sats_sol_multi: int
        num_sats_tracked: int
        position_type: nv_oem6_position_type.nv_position_type_t
        reserved: int
        sol_age: float
        solution_stat: nv_oem6_solution_status.nv_solution_status_t
        undulation: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_BESTPOS.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_BESTPOS.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_BESTPOS) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_BESTPOS) -> None: ...
    def assign(self) -> Message_NV_OEM6_BESTPOS: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_GENERIC_FRAME(gnss_message):
    header: nv_oem6_header_t
    msg_body: List[int]
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_GENERIC_FRAME) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_GENERIC_FRAME) -> None: ...
    def assign(self) -> Message_NV_OEM6_GENERIC_FRAME: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_GENERIC_SHORT_FRAME(gnss_message):
    header: nv_oem6_short_header_t
    msg_body: List[int]
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_GENERIC_SHORT_FRAME) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_GENERIC_SHORT_FRAME) -> None: ...
    def assign(self) -> Message_NV_OEM6_GENERIC_SHORT_FRAME: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_INSCOVS(gnss_message):
    class content_t:
        crc: int
        header: nv_oem6_short_header_t
        seconds_in_week: float
        week: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_INSCOVS.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_INSCOVS.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_INSCOVS) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_INSCOVS) -> None: ...
    def assign(self) -> Message_NV_OEM6_INSCOVS: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_INSPVAS(gnss_message):
    class content_t:
        azimuth: float
        crc: int
        header: nv_oem6_short_header_t
        hgt: float
        ins_status: nv_oem6_ins_status_type.nv_ins_status_type_t
        lat: float
        lon: float
        pitch: float
        roll: float
        seconds_in_week: float
        vel_east: float
        vel_north: float
        vel_up: float
        week: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_INSPVAS.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_INSPVAS.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_INSPVAS) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_INSPVAS) -> None: ...
    def assign(self) -> Message_NV_OEM6_INSPVAS: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_IONUTC(gnss_message):
    class content_t:
        A0: float
        A1: float
        a0: float
        a1: float
        a2: float
        a3: float
        b0: float
        b1: float
        b2: float
        b3: float
        crc: int
        deltat_ls: int
        deltat_lsf: int
        dn: int
        header: nv_oem6_header_t
        reserved: int
        tot: int
        utc_wn: int
        wn_lsf: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_IONUTC.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_IONUTC.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_IONUTC) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_IONUTC) -> None: ...
    def assign(self) -> Message_NV_OEM6_IONUTC: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_MARK2TIME(gnss_message):
    class content_t:
        clock_offset: float
        clock_offset_std: float
        clock_status: int
        crc: int
        header: nv_oem6_header_t
        utc_offset: float
        week: int
        week_seconds: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_MARK2TIME.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_MARK2TIME.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_MARK2TIME) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_MARK2TIME) -> None: ...
    def assign(self) -> Message_NV_OEM6_MARK2TIME: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_MARKPOS(gnss_message):
    class content_t:
        crc: int
        datum_id: int
        diff_age: float
        ext_sol_stat: int
        galileo_beidou_mask: int
        gps_glonass_mask: int
        header: nv_oem6_header_t
        hgt: float
        hgt_sigma: float
        lat: float
        lat_sigma: float
        lon: float
        lon_sigma: float
        num_sats_sol: int
        num_sats_sol_L1: int
        num_sats_sol_multi: int
        num_sats_tracked: int
        position_type: nv_oem6_position_type.nv_position_type_t
        reserved: int
        sol_age: float
        solution_stat: nv_oem6_solution_status.nv_solution_status_t
        undulation: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_MARKPOS.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_MARKPOS.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_MARKPOS) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_MARKPOS) -> None: ...
    def assign(self) -> Message_NV_OEM6_MARKPOS: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_MARKTIME(gnss_message):
    class content_t:
        clock_offset: float
        clock_offset_std: float
        clock_status: int
        crc: int
        header: nv_oem6_header_t
        utc_offset: float
        week: int
        week_seconds: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_MARKTIME.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_MARKTIME.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_MARKTIME) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_MARKTIME) -> None: ...
    def assign(self) -> Message_NV_OEM6_MARKTIME: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_RANGECMP(gnss_message):
    class TCompressedRangeLog:
        def __init__(self) -> None: ...
    crc: int
    header: nv_oem6_header_t
    num_obs: int
    obs_data: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RANGECMP) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RANGECMP) -> None: ...
    def assign(self) -> Message_NV_OEM6_RANGECMP: ...

class Message_NV_OEM6_RAWEPHEM(gnss_message):
    class content_t:
        crc: int
        header: nv_oem6_header_t
        ref_secs: int
        ref_week: int
        sat_prn: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_RAWEPHEM.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_RAWEPHEM.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RAWEPHEM) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RAWEPHEM) -> None: ...
    def assign(self) -> Message_NV_OEM6_RAWEPHEM: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_RAWIMUS(gnss_message):
    class content_t:
        accel_x: int
        accel_y_neg: int
        accel_z: int
        crc: int
        gyro_x: int
        gyro_y_neg: int
        gyro_z: int
        header: nv_oem6_short_header_t
        imu_status: int
        week: int
        week_seconds: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_RAWIMUS.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_RAWIMUS.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RAWIMUS) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RAWIMUS) -> None: ...
    def assign(self) -> Message_NV_OEM6_RAWIMUS: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_RXSTATUS(gnss_message):
    class content_t:
        aux1stat: int
        aux1stat_clear: int
        aux1stat_pri: int
        aux1stat_set: int
        aux2stat: int
        aux2stat_clear: int
        aux2stat_pri: int
        aux2stat_set: int
        aux3stat: int
        aux3stat_clear: int
        aux3stat_pri: int
        aux3stat_set: int
        crc: int
        error: int
        header: nv_oem6_header_t
        num_stats: int
        rxstat: int
        rxstat_clear: int
        rxstat_pri: int
        rxstat_set: int
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: Message_NV_OEM6_RXSTATUS.content_t) -> None: ...
        def assign(self) -> Message_NV_OEM6_RXSTATUS.content_t: ...
    fields: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RXSTATUS) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_RXSTATUS) -> None: ...
    def assign(self) -> Message_NV_OEM6_RXSTATUS: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_NV_OEM6_VERSION(gnss_message):
    class TComponentVersion:
        type: int
        def __init__(self) -> None: ...
    components: Any
    crc: int
    header: nv_oem6_header_t
    num_comps: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_VERSION) -> None: ...
    @overload
    def __init__(self, arg0: Message_NV_OEM6_VERSION) -> None: ...
    def assign(self) -> Message_NV_OEM6_VERSION: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class Message_TOPCON_PZS(gnss_message):
    Fix: int
    PSigma: float
    RTK_height_meters: float
    RXBattery: int
    TXBattery: int
    angle_transmitter: float
    cartesian_vx: float
    cartesian_vy: float
    cartesian_vz: float
    cartesian_x: float
    cartesian_y: float
    cartesian_z: float
    error: int
    hasCartesianPosVel: bool
    hasPosCov: bool
    hasStats: bool
    hasVelCov: bool
    height_meters: float
    latitude_degrees: float
    longitude_degrees: float
    nId: int
    pos_covariance: mrpt.pymrpt.mrpt.math.CMatrixFixed_float_4UL_4UL_t
    stats_GLONASS_sats_used: int
    stats_GPS_sats_used: int
    stats_rtk_fix_progress: int
    vel_covariance: mrpt.pymrpt.mrpt.math.CMatrixFixed_float_4UL_4UL_t
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_TOPCON_PZS) -> None: ...
    @overload
    def __init__(self, arg0: Message_TOPCON_PZS) -> None: ...
    def assign(self) -> Message_TOPCON_PZS: ...

class Message_TOPCON_SATS(gnss_message):
    AZs: List[int]
    ELs: List[int]
    USIs: List[int]
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Message_TOPCON_SATS) -> None: ...
    @overload
    def __init__(self, arg0: Message_TOPCON_SATS) -> None: ...
    def assign(self) -> Message_TOPCON_SATS: ...

class UTC_time:
    __hash__: ClassVar[None] = ...
    hour: int
    minute: int
    sec: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: UTC_time) -> None: ...
    def assign(self) -> UTC_time: ...
    def getAsTimestamp(self, date: mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> mrpt.pymrpt.std.chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
    @overload
    def readFromStream(self, in: mrpt.pymrpt.mrpt.serialization.CArchive) -> None: ...
    @overload
    def readFromStream(classmrpt) -> void: ...
    @overload
    def writeToStream(self, out: mrpt.pymrpt.mrpt.serialization.CArchive) -> None: ...
    @overload
    def writeToStream(classmrpt) -> void: ...
    def __eq__(self, o: UTC_time) -> bool: ...
    def __ne__(self, o: UTC_time) -> bool: ...

class gnss_message:
    message_type: gnss_message_type_t
    def __init__(self, *args, **kwargs) -> None: ...
    def Factory(self, *args, **kwargs) -> Any: ...
    def FactoryKnowsMsgType(self, *args, **kwargs) -> Any: ...
    def assign(self) -> gnss_message: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...
    def getMessageTypeAsString(self) -> str: ...
    @overload
    def isOfType(self, type_id: gnss_message_type_t) -> bool: ...
    @overload
    def isOfType(constenummrpt) -> bool: ...
    def readAndBuildFromStream(self, *args, **kwargs) -> Any: ...
    @overload
    def readFromStream(self, in: mrpt.pymrpt.mrpt.serialization.CArchive) -> None: ...
    @overload
    def readFromStream(classmrpt) -> void: ...
    @overload
    def writeToStream(self, out: mrpt.pymrpt.mrpt.serialization.CArchive) -> None: ...
    @overload
    def writeToStream(classmrpt) -> void: ...

class gnss_message_type_t:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    NMEA_GGA: ClassVar[gnss_message_type_t] = ...
    NMEA_GLL: ClassVar[gnss_message_type_t] = ...
    NMEA_GSA: ClassVar[gnss_message_type_t] = ...
    NMEA_GSV: ClassVar[gnss_message_type_t] = ...
    NMEA_MSS: ClassVar[gnss_message_type_t] = ...
    NMEA_RMC: ClassVar[gnss_message_type_t] = ...
    NMEA_VTG: ClassVar[gnss_message_type_t] = ...
    NMEA_ZDA: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_ALIGNBSLNENU: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_ALIGNBSLNXYZ: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_ALIGNDOP: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_BESTPOS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_BESTSATS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_BESTUTM: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_BESTVEL: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_BESTXYZ: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_CLOCKSTEERING: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GENERIC_FRAME: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GENERIC_SHORT_FRAME: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPGGA: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPGGARTK: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPGLL: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPGSA: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPGSV: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPHDT: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPRMC: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPVTG: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_GPZDA: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_INSATTS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_INSCOVS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_INSPVAS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_INSVELS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_IONUTC: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_MARK2POS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_MARK2TIME: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_MARKPOS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_MARKTIME: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_MSG2ENUM: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_PPPPOS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_RANGECMP: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_RAWEPHEM: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_RAWIMUS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_RXSTATUS: ClassVar[gnss_message_type_t] = ...
    NV_OEM6_VERSION: ClassVar[gnss_message_type_t] = ...
    TOPCON_PZS: ClassVar[gnss_message_type_t] = ...
    TOPCON_SATS: ClassVar[gnss_message_type_t] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class nv_oem6_header_t:
    hdr_len: int
    idle_percent: int
    ms_in_week: int
    msg_id: int
    msg_len: int
    msg_type: int
    port_addr: int
    receiver_status: int
    receiver_sw_version: int
    reserved: int
    seq_number: int
    time_status: int
    week: int
    @overload
    def __init__(self, arg0: nv_oem6_header_t) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> nv_oem6_header_t: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...

class nv_oem6_short_header_t:
    ms_in_week: int
    msg_id: int
    msg_len: int
    week: int
    @overload
    def __init__(self, arg0: nv_oem6_short_header_t) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> nv_oem6_short_header_t: ...
    @overload
    def fixEndianness(self) -> None: ...
    @overload
    def fixEndianness() -> void: ...



from typing import Any, Iterator

from typing import overload

class array_mrpt_img_CImage_6UL_t:
    @overload
    def __init__(self, arg0: array_mrpt_img_CImage_6UL_t) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> array_mrpt_img_CImage_6UL_t: ...
    def at(self, *args, **kwargs) -> Any: ...
    def back(self, *args, **kwargs) -> Any: ...
    def begin(self, *args, **kwargs) -> Any: ...
    def cbegin(self, *args, **kwargs) -> Any: ...
    def cend(self, *args, **kwargs) -> Any: ...
    def data(self, *args, **kwargs) -> Any: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def end(self, *args, **kwargs) -> Any: ...
    @overload
    def fill(self, __u) -> None: ...
    @overload
    def fill(constclassmrpt) -> void: ...
    def front(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    def swap(self, __other: array_mrpt_img_CImage_6UL_t) -> None: ...
    def __getitem__(self, index) -> Any: ...

class deque_mrpt_bayes_CProbabilityParticle_mrpt_maps_CRBPFParticleData_mrpt_bayes_particle_storage_mode_POINTER_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __n: int) -> None: ...
    @overload
    def __init__(self, arg0: deque_mrpt_bayes_CProbabilityParticle_mrpt_maps_CRBPFParticleData_mrpt_bayes_particle_storage_mode_POINTER_t) -> None: ...
    def assign(self, __x: deque_mrpt_bayes_CProbabilityParticle_mrpt_maps_CRBPFParticleData_mrpt_bayes_particle_storage_mode_POINTER_t) -> deque_mrpt_bayes_CProbabilityParticle_mrpt_maps_CRBPFParticleData_mrpt_bayes_particle_storage_mode_POINTER_t: ...
    def at(self, *args, **kwargs) -> Any: ...
    def back(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def front(self, *args, **kwargs) -> Any: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def pop_back(self) -> None: ...
    @overload
    def pop_back() -> void: ...
    @overload
    def pop_front(self) -> None: ...
    @overload
    def pop_front() -> void: ...
    @overload
    def resize(self, __new_size: int) -> None: ...
    @overload
    def resize(size_t) -> void: ...
    @overload
    def shrink_to_fit(self) -> None: ...
    @overload
    def shrink_to_fit() -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: deque_mrpt_bayes_CProbabilityParticle_mrpt_maps_CRBPFParticleData_mrpt_bayes_particle_storage_mode_POINTER_t) -> None: ...
    @overload
    def swap(classstd, mrpt) -> void: ...
    def __getitem__(self, index) -> Any: ...
    def __iter__(self) -> Iterator: ...

class deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose2D_mrpt_bayes_particle_storage_mode_VALUE_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __n: int) -> None: ...
    @overload
    def __init__(self, arg0: deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose2D_mrpt_bayes_particle_storage_mode_VALUE_t) -> None: ...
    @overload
    def assign(self, __x: deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose2D_mrpt_bayes_particle_storage_mode_VALUE_t) -> deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose2D_mrpt_bayes_particle_storage_mode_VALUE_t: ...
    @overload
    def assign(size_t, conststructmrpt, mrpt) -> void: ...
    def at(self, *args, **kwargs) -> Any: ...
    def back(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def front(self, *args, **kwargs) -> Any: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def pop_back(self) -> None: ...
    @overload
    def pop_back() -> void: ...
    @overload
    def pop_front(self) -> None: ...
    @overload
    def pop_front() -> void: ...
    def push_back(self, conststructmrpt, mrpt) -> void: ...
    def push_front(self, conststructmrpt, mrpt) -> void: ...
    @overload
    def resize(self, __new_size: int) -> None: ...
    @overload
    def resize(size_t) -> void: ...
    @overload
    def resize(size_t, conststructmrpt, mrpt) -> void: ...
    @overload
    def shrink_to_fit(self) -> None: ...
    @overload
    def shrink_to_fit() -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose2D_mrpt_bayes_particle_storage_mode_VALUE_t) -> None: ...
    @overload
    def swap(classstd, mrpt) -> void: ...
    def __getitem__(self, index) -> Any: ...
    def __iter__(self) -> Iterator: ...

class deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose3D_mrpt_bayes_particle_storage_mode_VALUE_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __n: int) -> None: ...
    @overload
    def __init__(self, arg0: deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose3D_mrpt_bayes_particle_storage_mode_VALUE_t) -> None: ...
    @overload
    def assign(self, __x: deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose3D_mrpt_bayes_particle_storage_mode_VALUE_t) -> deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose3D_mrpt_bayes_particle_storage_mode_VALUE_t: ...
    @overload
    def assign(size_t, conststructmrpt, mrpt) -> void: ...
    def at(self, *args, **kwargs) -> Any: ...
    def back(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def front(self, *args, **kwargs) -> Any: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def pop_back(self) -> None: ...
    @overload
    def pop_back() -> void: ...
    @overload
    def pop_front(self) -> None: ...
    @overload
    def pop_front() -> void: ...
    def push_back(self, conststructmrpt, mrpt) -> void: ...
    def push_front(self, conststructmrpt, mrpt) -> void: ...
    @overload
    def resize(self, __new_size: int) -> None: ...
    @overload
    def resize(size_t) -> void: ...
    @overload
    def resize(size_t, conststructmrpt, mrpt) -> void: ...
    @overload
    def shrink_to_fit(self) -> None: ...
    @overload
    def shrink_to_fit() -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: deque_mrpt_bayes_CProbabilityParticle_mrpt_math_TPose3D_mrpt_bayes_particle_storage_mode_VALUE_t) -> None: ...
    @overload
    def swap(classstd, mrpt) -> void: ...
    def __getitem__(self, index) -> Any: ...
    def __iter__(self) -> Iterator: ...

class deque_mrpt_math_TPose3D_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __a) -> None: ...
    @overload
    def __init__(self, __n: int) -> None: ...
    @overload
    def __init__(self, __n: int, __a) -> None: ...
    @overload
    def __init__(self, __n: int, __value) -> None: ...
    @overload
    def __init__(self, __n: int, __value, __a) -> None: ...
    @overload
    def __init__(self, arg0: deque_mrpt_math_TPose3D_t) -> None: ...
    @overload
    def __init__(self, __x: deque_mrpt_math_TPose3D_t, __a) -> None: ...
    @overload
    def assign(self, __x: deque_mrpt_math_TPose3D_t) -> deque_mrpt_math_TPose3D_t: ...
    @overload
    def assign(self, __n: int, __val) -> None: ...
    @overload
    def assign(size_t, conststructmrpt) -> void: ...
    def at(self, *args, **kwargs) -> Any: ...
    def back(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def front(self, *args, **kwargs) -> Any: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def pop_back(self) -> None: ...
    @overload
    def pop_back() -> void: ...
    @overload
    def pop_front(self) -> None: ...
    @overload
    def pop_front() -> void: ...
    @overload
    def push_back(self, __x) -> None: ...
    @overload
    def push_back(conststructmrpt) -> void: ...
    @overload
    def push_front(self, __x) -> None: ...
    @overload
    def push_front(conststructmrpt) -> void: ...
    @overload
    def resize(self, __new_size: int) -> None: ...
    @overload
    def resize(size_t) -> void: ...
    @overload
    def resize(self, __new_size: int, __x) -> None: ...
    @overload
    def resize(size_t, conststructmrpt) -> void: ...
    @overload
    def shrink_to_fit(self) -> None: ...
    @overload
    def shrink_to_fit() -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: deque_mrpt_math_TPose3D_t) -> None: ...
    @overload
    def swap(classstd) -> void: ...
    def __getitem__(self, index) -> Any: ...
    def __iter__(self) -> Iterator: ...

class deque_mrpt_system_CDirectoryExplorer_TFileInfo_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __a) -> None: ...
    @overload
    def __init__(self, __n: int) -> None: ...
    @overload
    def __init__(self, __n: int, __a) -> None: ...
    @overload
    def __init__(self, __n: int, __value) -> None: ...
    @overload
    def __init__(self, __n: int, __value, __a) -> None: ...
    @overload
    def __init__(self, arg0: deque_mrpt_system_CDirectoryExplorer_TFileInfo_t) -> None: ...
    @overload
    def __init__(self, __x: deque_mrpt_system_CDirectoryExplorer_TFileInfo_t, __a) -> None: ...
    @overload
    def assign(self, __x: deque_mrpt_system_CDirectoryExplorer_TFileInfo_t) -> deque_mrpt_system_CDirectoryExplorer_TFileInfo_t: ...
    @overload
    def assign(self, __n: int, __val) -> None: ...
    @overload
    def assign(size_t, conststructmrpt) -> void: ...
    def at(self, *args, **kwargs) -> Any: ...
    def back(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def front(self, *args, **kwargs) -> Any: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def pop_back(self) -> None: ...
    @overload
    def pop_back() -> void: ...
    @overload
    def pop_front(self) -> None: ...
    @overload
    def pop_front() -> void: ...
    @overload
    def push_back(self, __x) -> None: ...
    @overload
    def push_back(conststructmrpt) -> void: ...
    @overload
    def push_front(self, __x) -> None: ...
    @overload
    def push_front(conststructmrpt) -> void: ...
    @overload
    def resize(self, __new_size: int) -> None: ...
    @overload
    def resize(size_t) -> void: ...
    @overload
    def resize(self, __new_size: int, __x) -> None: ...
    @overload
    def resize(size_t, conststructmrpt) -> void: ...
    @overload
    def shrink_to_fit(self) -> None: ...
    @overload
    def shrink_to_fit() -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: deque_mrpt_system_CDirectoryExplorer_TFileInfo_t) -> None: ...
    @overload
    def swap(classstd) -> void: ...
    def __getitem__(self, index) -> Any: ...

class map_double_double_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __comp) -> None: ...
    @overload
    def __init__(self, arg0: map_double_double_t) -> None: ...
    def assign(self) -> map_double_double_t: ...
    def at(self, __k: float) -> float: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def count(self, __x: float) -> int: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def equal_range(self, *args, **kwargs) -> Any: ...
    def erase(self, __x: float) -> int: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    def insert(self, *args, **kwargs) -> Any: ...
    def key_comp(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    def swap(self, __x: map_double_double_t) -> None: ...
    def __getitem__(self, __k: float) -> float: ...

class map_mrpt_containers_yaml_node_t_mrpt_containers_yaml_node_t_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __comp) -> None: ...
    @overload
    def __init__(self, __comp, __a, mrpt) -> None: ...
    @overload
    def __init__(self, arg0: map_mrpt_containers_yaml_node_t_mrpt_containers_yaml_node_t_t) -> None: ...
    @overload
    def __init__(self, __a, mrpt) -> None: ...
    @overload
    def __init__(self, __m: map_mrpt_containers_yaml_node_t_mrpt_containers_yaml_node_t_t, __a, mrpt) -> None: ...
    def assign(self) -> map_mrpt_containers_yaml_node_t_mrpt_containers_yaml_node_t_t: ...
    def at(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def count(self, __x) -> int: ...
    @overload
    def count(conststructmrpt) -> size_t: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def equal_range(self, *args, **kwargs) -> Any: ...
    @overload
    def erase(self, __x) -> int: ...
    @overload
    def erase(conststructmrpt) -> size_t: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    def insert(self, *args, **kwargs) -> Any: ...
    def key_comp(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: map_mrpt_containers_yaml_node_t_mrpt_containers_yaml_node_t_t) -> None: ...
    @overload
    def swap(classstd, structmrpt) -> void: ...
    def __getitem__(self, index) -> Any: ...
    def __iter__(self) -> Iterator: ...

class map_std_string_double_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: map_std_string_double_t) -> None: ...
    def assign(self) -> map_std_string_double_t: ...
    def at(self, __k: str) -> float: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def count(self, __x: str) -> int: ...
    @overload
    def count(conststd) -> size_t: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def equal_range(self, *args, **kwargs) -> Any: ...
    @overload
    def erase(self, __x: str) -> int: ...
    @overload
    def erase(conststd) -> size_t: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    def insert(self, *args, **kwargs) -> Any: ...
    def key_comp(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    def swap(self, __x: map_std_string_double_t) -> None: ...
    def __getitem__(self, __k: str) -> float: ...

class map_std_string_mrpt_poses_CPose3D_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: map_std_string_mrpt_poses_CPose3D_t) -> None: ...
    def assign(self) -> map_std_string_mrpt_poses_CPose3D_t: ...
    def at(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def count(self, __x: str) -> int: ...
    @overload
    def count(conststd) -> size_t: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def equal_range(self, *args, **kwargs) -> Any: ...
    @overload
    def erase(self, __x: str) -> int: ...
    @overload
    def erase(conststd) -> size_t: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    def insert(self, *args, **kwargs) -> Any: ...
    def key_comp(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: map_std_string_mrpt_poses_CPose3D_t) -> None: ...
    @overload
    def swap(classstd, classmrpt) -> void: ...
    def __getitem__(self, index) -> Any: ...

class map_std_string_std_string_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: map_std_string_std_string_t) -> None: ...
    def assign(self) -> map_std_string_std_string_t: ...
    def at(self, __k: str) -> str: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def count(self, __x: str) -> int: ...
    @overload
    def count(conststd) -> size_t: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def equal_range(self, *args, **kwargs) -> Any: ...
    @overload
    def erase(self, __x: str) -> int: ...
    @overload
    def erase(conststd) -> size_t: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    def insert(self, *args, **kwargs) -> Any: ...
    def key_comp(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: map_std_string_std_string_t) -> None: ...
    @overload
    def swap(classstd, std) -> void: ...
    def __getitem__(self, __k: str) -> str: ...

class multimap_std_chrono_time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_std_shared_ptr_mrpt_serialization_CSerializable_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: multimap_std_chrono_time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_std_shared_ptr_mrpt_serialization_CSerializable_t) -> None: ...
    def assign(self) -> multimap_std_chrono_time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_std_shared_ptr_mrpt_serialization_CSerializable_t: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def count(self, __x: chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> int: ...
    @overload
    def count(constmrpt) -> size_t: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def equal_range(self, *args, **kwargs) -> Any: ...
    @overload
    def erase(self, __x: chrono.time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> int: ...
    @overload
    def erase(constmrpt) -> size_t: ...
    def get_allocator(self, *args, **kwargs) -> Any: ...
    def key_comp(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    def swap(self, __x: multimap_std_chrono_time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_std_shared_ptr_mrpt_serialization_CSerializable_t) -> None: ...
    def __iter__(self) -> Iterator: ...

class vector_std_string_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __n: int) -> None: ...
    @overload
    def __init__(self, __n: int, __value: str) -> None: ...
    @overload
    def __init__(self, arg0: vector_std_string_t) -> None: ...
    @overload
    def assign(self, __x: vector_std_string_t) -> vector_std_string_t: ...
    @overload
    def assign(self, __n: int, __val: str) -> None: ...
    @overload
    def assign(size_t, conststd) -> void: ...
    def at(self, __n: int) -> str: ...
    def back(self) -> str: ...
    def begin(self, *args, **kwargs) -> Any: ...
    @overload
    def capacity(self) -> int: ...
    @overload
    def capacity() -> size_t: ...
    def cbegin(self, *args, **kwargs) -> Any: ...
    def cend(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def data(self) -> str: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def end(self, *args, **kwargs) -> Any: ...
    def erase(self, *args, **kwargs) -> Any: ...
    def front(self) -> str: ...
    def insert(self, *args, **kwargs) -> Any: ...
    @overload
    def max_size(self) -> int: ...
    @overload
    def max_size() -> size_t: ...
    @overload
    def pop_back(self) -> None: ...
    @overload
    def pop_back() -> void: ...
    @overload
    def push_back(self, __x: str) -> None: ...
    @overload
    def push_back(conststd) -> void: ...
    @overload
    def reserve(self, __n: int) -> None: ...
    @overload
    def reserve(size_t) -> void: ...
    @overload
    def resize(self, __new_size: int) -> None: ...
    @overload
    def resize(size_t) -> void: ...
    @overload
    def resize(self, __new_size: int, __x: str) -> None: ...
    @overload
    def resize(size_t, conststd) -> void: ...
    @overload
    def shrink_to_fit(self) -> None: ...
    @overload
    def shrink_to_fit() -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    @overload
    def swap(self, __x: vector_std_string_t) -> None: ...
    @overload
    def swap(classstd) -> void: ...
    def __getitem__(self, __n: int) -> str: ...
    def __iter__(self) -> Iterator: ...
